@@ -89,9 +89,23 @@ refresh_model_row(GNCImportMainMatcher *gui, GtkTreeModel *model,
 
 void gnc_gen_trans_list_delete (GNCImportMainMatcher *info)
 {
+  GtkTreeModel *model;
+  GtkTreeIter iter;
+  GNCImportTransInfo *trans_info;
+
   if (info == NULL) 
     return;
 
+  model = gtk_tree_view_get_model(info->view);
+  if (gtk_tree_model_get_iter_first(model, &iter)) {
+    do {
+      gtk_tree_model_get(model, &iter,
+		         DOWNLOADED_COL_DATA, &trans_info,
+		         -1);
+      gnc_import_TransInfo_delete(trans_info);
+    } while (gtk_tree_model_iter_next (model, &iter));
+  }
+
   gnc_save_window_size(GCONF_SECTION, GTK_WINDOW(info->dialog));
   gnc_import_Settings_delete (info->user_settings);
   gtk_widget_destroy (GTK_WIDGET (info->dialog));
